@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP                        #-}
 {-# LANGUAGE DeriveDataTypeable         #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
 {-# LANGUAGE DeriveTraversable          #-}
@@ -5,9 +6,9 @@
 -- |
 -- Module      :  $Header$
 -- Description :  Data.IntMap with Enum keys.
--- Copyright   :  (c) 2011-2013 Michal Terepeta
+-- Copyright   :  (c) 2011-2019 Michal Terepeta
 -- License     :  BSD3
--- Maintainer  :  michal.terepeta@gmail.com
+-- Maintainer  :  mikolaj.konarski@funktory.com
 -- Stability   :  alpha
 -- Portability :  uses DeriveDataTypeable and GeneralizedNewtypeDeriving
 
@@ -122,6 +123,10 @@ module Data.EnumMap.Base
   -- * Filter
   , filter
   , filterWithKey
+#if (MIN_VERSION_containers(0,5,8))
+  , restrictKeys
+  , withoutKeys
+#endif
   , partition
   , partitionWithKey
 
@@ -507,6 +512,18 @@ filterWithKey :: (Enum k) => (k -> a -> Bool) -> EnumMap k a -> EnumMap k a
 filterWithKey p = EnumMap . I.filterWithKey (p . toEnum) . unWrap
 {-# INLINE filterWithKey #-}
 
+#if (MIN_VERSION_containers(0,5,8))
+restrictKeys :: (Enum k) => EnumMap k a -> EnumSet k -> EnumMap k a
+restrictKeys m s =
+  EnumMap $ I.restrictKeys (unWrap m) (EnumSet.enumSetToIntSet s)
+{-# INLINE restrictKeys #-}
+
+withoutKeys :: (Enum k) => EnumMap k a -> EnumSet k -> EnumMap k a
+withoutKeys m s =
+  EnumMap $ I.withoutKeys (unWrap m) (EnumSet.enumSetToIntSet s)
+{-# INLINE withoutKeys #-}
+#endif
+
 partition :: (a -> Bool) -> EnumMap k a -> (EnumMap k a, EnumMap k a)
 partition p = (EnumMap *** EnumMap) . I.partition p . unWrap
 {-# INLINE partition #-}
